pub struct CryptoEngine { /* private fields */ }Expand description
Crypto engine for encryption/decryption operations
Implementations
Sourceimpl CryptoEngine
impl CryptoEngine
Sourcepub fn derive_key(
&self,
password: &str,
salt: &[u8; 32],
) -> Result<SecureKey, CryptoError>
pub fn derive_key( &self, password: &str, salt: &[u8; 32], ) -> Result<SecureKey, CryptoError>
Derive a secure key from password and salt using Argon2
Sourcepub fn encrypt(
&self,
data: &[u8],
password: &str,
metadata: FileMetadata,
) -> Result<Vec<u8>, CryptoError>
pub fn encrypt( &self, data: &[u8], password: &str, metadata: FileMetadata, ) -> Result<Vec<u8>, CryptoError>
Encrypt data with password and metadata
Sourcepub fn decrypt(
&self,
encrypted_data: &[u8],
password: &str,
) -> Result<(Vec<u8>, FileMetadata), CryptoError>
pub fn decrypt( &self, encrypted_data: &[u8], password: &str, ) -> Result<(Vec<u8>, FileMetadata), CryptoError>
Decrypt data with password, returning both data and metadata
Sourcepub fn decrypt_legacy(
&self,
encrypted_data: &[u8],
password: &str,
) -> Result<Vec<u8>, CryptoError>
pub fn decrypt_legacy( &self, encrypted_data: &[u8], password: &str, ) -> Result<Vec<u8>, CryptoError>
Legacy decrypt method for backward compatibility